@@ -12,22 +12,29 @@ class CryptoDataStream(BaseStream):
 
     def __init__(
         self,
-        api_key: str = None,
-        secret_key: str = None,
+        api_key: str,
+        secret_key: str,
         raw_data: bool = False,
+        url_override: Optional[str] = None,
         websocket_params: Optional[Dict] = None,
     ) -> None:
         """
         Instantiates a WebSocket client for accessing live cryptocurrency data.
 
         Args:
-            api_key (str): Alpaca API key. Defaults to None.
-            secret_key (str): Alpaca API secret key. Defaults to None.
+            api_key (str): Alpaca API key.
+            secret_key (str): Alpaca API secret key.
             raw_data (bool, optional): Whether to return wrapped data or raw API data. Defaults to False.
             websocket_params (Optional[Dict], optional): Any parameters for configuring websocket connection. Defaults to None.
+            url_override (Optional[str]): If specified allows you to override the base url the client
+              points to for proxy/testing. Defaults to None.
         """
         super().__init__(
-            endpoint=BaseURL.MARKET_DATA_STREAM.value + "/v1beta2/crypto",
+            endpoint=(
+                url_override
+                if url_override is not None
+                else BaseURL.MARKET_DATA_STREAM.value + "/v1beta2/crypto",
+            ),
             api_key=api_key,
             secret_key=secret_key,
             raw_data=raw_data,
